<?php

/**
 * @file
 * File nys_url_alias_audit.drush.inc.
 */

/**
 * Implements hook_drush_help().
 */
function exerciser_drush_help($command) {
  switch ($command) {
    case 'drush:exercise':
      return dt('Run exercise');

  }
}

/**
 * Implements hook_drush_command().
 */
function exerciser_drush_command() {
  $items = array();

  $items['exercise-nodes'] = array(
    'description' => dt('Exercises (renders) the pages of a Content Type.'),
    'arguments'   => array(
      'arg1'    => dt('An optional content type.'),
    ),
    'options' => array(
      'continue' => 'continue going with failed run.',
      'flush' => 'Reset Run Data.',
      'quietly' => 'Only Show if messages.',
      'db' => 'Emit a message for each row.',
    ),
    'examples' => array(
      'Standard example' => 'exercise',
      'Argument example' => 'exercise basic',
    ),
    'aliases' => array('exns'),
  );

  $items['exercise-terms'] = array(
    'description' => dt('Exercises (renders) the pages of a Taxonomy Vocabulary.'),
    'arguments'   => array(
      'arg1'    => dt('An optional vocabulary id type.'),
    ),
    'examples' => array(
      'Standard example' => 'exercise-terms',
      'Argument example' => 'exercise-terms 11',
    ),
    'options' => array(
      'db' => 'Emit a message for each row.',
    ),
    'aliases' => array('exts'),
  );

  $items['exercise-node'] = array(
    'description' => dt('Exercises (renders) a Node Page.'),
    'arguments'   => array(
      'arg1'    => dt('An optional nid or path.'),
    ),
    'options' => array(
      'continue' => 'continue going with failed run.',
      'flush' => 'Reset Run Data.',
      'quietly' => 'Only Show if messages.',
    ),
    'examples' => array(
      'Standard example' => 'exercise',
      'Argument example' => 'exercise basic',
    ),
    'aliases' => array('exn'),
  );

  $items['exercise-term'] = array(
    'description' => dt('Exercies (renders) a Term Page.'),
    'arguments'   => array(
      'arg1'    => dt('An optional tid or path.'),
    ),
    'examples' => array(
      'Standard example' => 'exercise-terms',
      'Argument example' => 'exercise-terms 11',
    ),
    'aliases' => array('ext'),
  );


  $items['exercise-status'] = array(
    'description' => dt('Shows System Status.'),
    'arguments'   => array(
      'arg1'    => dt('An optional tid or path.'),
    ),
    'examples' => array(
      'Standard example' => 'exercise-status',
      'Argument example' => 'exercise-status',
    ),
    'aliases' => array('est'),
  );

  $items['exercise-status-ping'] = array(
  'description' => dt('Shows Detailed Status.'),
  'arguments'   => array(
    'arg1'    => dt('An optional tid or path.'),
  ),
  'examples' => array(
    'Standard example' => 'exercise-terms',
    'Argument example' => 'exercise-terms 11',
  ),
  'aliases' => array('esp'),
  );

  $items['exercise-stop'] = array(
    'description' => dt('Shows System Status.'),
    'arguments'   => array(
      'arg1'    => dt('An optional tid or path.'),
    ),
    'options' => array(
      'full' => 'Clear previous run also.',
    ),
    'examples' => array(
      'Standard example' => 'exercise-stop',
      'Argument example' => 'exercise-stop',
    ),
    'aliases' => array('estp'),
  );

  $items['exercise-all'] = array(
    'description' => dt('Generates Drush Script.'),
    'arguments'   => array(
      'arg1'    => dt('Static or Active using next.'),
    ),
    'examples' => array(
      'Standard example' => 'exercise-all',
      'Argument example' => 'exercise-all',
    ),
    'aliases' => array('exa'),
  );

  $items['exercise-get-last-complete-run'] = array(
    'description' => dt('Gets the type of the last complete run.'),
    'arguments'   => array(
      'arg1'    => dt('No Options ????.'),
    ),
    'examples' => array(
      'Standard example' => 'exercise-get-last-complete-run',
      'Argument example' => 'exercise-get-last-complete-run',
    ),
    'aliases' => array('exlcr'),
  );

  $items['exercise-get-next-run'] = array(
    'description' => dt('Gets the name of the next type to run.'),
    'arguments'   => array(
      'arg1'    => dt('No options.'),
    ),
    'options' => array(
      'command' => 'Get as a drush command.',
    ),
    'examples' => array(
      'Standard example' => 'exercise-get-next-run',
      'Argument example' => 'exercise-get-next-run',
    ),
    'aliases' => array('exgnr'),
  );


  /////////////////////////////////////
  $items['exercise-test'] = array(
  'description' => dt('Shows Detailed Status.'),
  'arguments'   => array(
    'arg1'    => dt('An optional tid or path.'),
  ),
  'options' => array(
    'db' => 'Emit a message for each row.',
  ),
  'examples' => array(
    'Standard example' => 'exercise-terms',
    'Argument example' => 'exercise-terms 11',
  ),
  'aliases' => array('et'),
);




  return $items;
}


/**
 * Callback function for drush exercise-nodes - exns.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_nodes($arg1 = NULL) {
  $retval = exerciser_exercise_nodes($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Nodes.', 'ok');
}


/**
 * Callback function for drush exercise-terms - exts.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_terms($arg1 = NULL) {
  $retval = exerciser_exercise_terms($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Terms.', 'ok');
}

/*
 * Callback function for drush exercise-node - exn.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_node($arg1 = NULL) {
  $retval = exerciser_exercise_node_drush($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Node.', 'ok');
}


/**
 * Callback function for drush exercise-term - ext.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_term($arg1 = NULL) {
  $retval = exerciser_exercise_term_drush($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Term.', 'ok');
}

/**
 * Callback function for drush exercise-status - est.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_status($arg1 = NULL) {
  $retval = exerciser_exercise_status($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Status.', 'ok');
}

/**
 * Callback function for drush exercise-status-ping - esp.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_status_ping($arg1 = NULL) {
  $retval = exerciser_exercise_status_ping($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Status Ping.', 'ok');
}

/**
 * Callback function for drush exercise-status - estp.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_stop($arg1 = NULL) {
  $status = exerciser_exercise_get_status($arg1);
  drush_confirm("Are you sure you want to stop the `$status` run ?", $indent = 0);

  $retval = exerciser_exercise_stop($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Stop the exerciser.', 'ok');
}

/**
 * Callback function for drush exercise-all - exa.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_all($arg1 = NULL) {

  $retval = exerciser_exercise_all($arg1);
}

/**
 * Callback function for drush exercise-get-last-complete-run - exlcr.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_get_last_complete_run($arg1 = NULL) {

  $retval = exerciser_exercise_get_last_complete_run($arg1);
}

/**
 * Callback function for drush exercise-get-next-run - exgnr.
 *
 * Callback is called by using drush_hook_command() where
 * hook is the name of the module (MYMODULE) and command is the name of
 * the Drush command with all "-" characters
 * converted to "_" characters (my_command).
 *
 * $arg1
 *   An optional argument
 */
function drush_exerciser_exercise_get_next_run($arg1 = NULL) {

  $retval = exerciser_exercise_get_next_run($arg1);
}

//-------------------------------------------------------------
function drush_exerciser_exercise_test($arg1 = NULL) {
  $retval = exerciser_exercise_test($arg1);
  drush_log($retval, 'ok');

  // Log to the command line with an OK status.
  drush_log('Completed Exercise Status Test.', 'ok');
}
